#!/usr/bin/perl -w
#
################################################################################
# foremost.conf_converter.pl
# 
# This script converts an original foremost.conf to a  format 
# suitable for use with the Autopsy patch.
# It consists of 'dumb' regular expressions, so if you 
# have your own custom foremost.conf, there might be dragons.
# You will lose the comments though, add them manually if you want them.
#
# You'll find a sample foremost.conf for Autopsy with the patch 
# (with comments)
#
# Author:      Pepijn Vissers (vissers@fox-it.com) 
#
# Copyright 2003 Fox-IT Forensic IT Experts B.V.
#
# foremost.conf_converter.pl is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# foremost.conf_converter.pl is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# 
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
# 
################################################################################

use Getopt::Std;

getopts("i:o:");

if (!$opt_i || !$opt_o) {
	&usage;
}

my $infile = $opt_i;
my $outfile = $opt_o;

open(IN, "<$infile") or die "Oops. Cannot open $infile ($!)\n";
open(OUT, ">$outfile") or die "Oops. Cannot open $outfile ($!)\n";

while (<IN>) {

      next unless (/#?\s+[\.\w]+\s+[yn]\s+/ || /^wildcard/);

      if ( (!/#?\s+[\.\w]+\s+[yn]\s+\d/) && (!/^wildcard/) ) {

        print "\n!! WARNING: detected line with no 'max_size' defined!\n".
              "Please edit $outfile by hand to correct this, otherwise you will encounter parsing errors.\n".
              "Line detected: $_\n";
      }
      
      s/^#\s+/#/;
      s/^\s+//;
      s/^#?\.//;   # a dot in the 'ext' field gives double dots with the output (foo..pgp instead of foo.pgp).

      print OUT $_;
	
}

close OUT; close IN;

sub usage {
 print "\nUsage: ".
       "$0 -i <inputfile> -o <outputfile>\n\n";
       exit(0);
}
